==> aeon-0.3.0.tar.gz: aeon-0.3.0/docs/index.md <==
---
hide-toc: true
---

```{image} images/logo/aeon-logo-blue-compact.png
:align: center
:alt: aeon logo
:width: 80%
```
# Welcome to the documentation for **aeon**

<br>

- scikit learn compatible Framework for time series tasks such as forecasting and
classification.
- Provides a broad library of time series algorithms, including the latest advances.
- Efficient implementation of time series algorithms using numba.
- Interfaces with other time series packages to provide a single framework for algorithm
comparison.

<br>

::::{grid} 1 2 2 2
:gutter: 3

:::{grid-item-card}
:img-top: examples/img/forecasting2.png
:text-align: center

Forecasting

^^^

Get started with time series forecasting.

+++

```{button-ref} /examples/01_forecasting.ipynb
:color: primary
:click-parent:
:expand:

Forecasting
```

:::

:::{grid-item-card}
:img-top: examples/img/tsc.png
:text-align: center

Classification

^^^

Get started with time series classification.

+++

```{button-ref} /examples/classification/classification.ipynb
:color: primary
:click-parent:
:expand:

Classification
```

:::

:::{grid-item-card}
:img-top: examples/img/tser.png
:text-align: center

Regression

^^^

Get started with time series extrinsic regression.

+++

```{button-ref} examples-regression
:color: primary
:click-parent:
:expand:

Regression
```

:::

:::{grid-item-card}
:img-top: examples/img/tscl.png
:text-align: center

Clustering

^^^

Get started with time series clustering.

+++

```{button-ref} examples-clustering
:color: primary
:click-parent:
:expand:

Clustering
```

:::

:::{grid-item-card}
:img-top: examples/img/transformation.png
:text-align: center

Transformation

^^^

Get started with time series transformations.

+++

```{button-ref} examples-transformation
:color: primary
:click-parent:
:expand:

Transformation
```

:::

::::

## Community Channels

**GitHub**: [github.com/aeon-toolkit/aeon](https://github.com/aeon-toolkit/aeon)

**Slack**: [aeon slack](https://join.slack.com/t/aeon-toolkit/shared_invite/zt-1plkevy4x-vAg1dAUXcuoR38FjY9nxzg)

**Twitter**: [twitter/aeon-toolkit](https://twitter.com/aeon_toolkit)

**LinkedIn**: [linkedin/aeon-toolkit](https://www.linkedin.com/company/aeon-toolkit)

```{toctree}
:caption: Using aeon
:hidden:

installation
getting_started.md
user_guide
api_reference
examples.md
```

```{toctree}
:caption: Developing aeon
:hidden:

get_involved
developers
```

```{toctree}
:caption: The aeon team
:hidden:

contributors.md
about.md
```

```{toctree}
:caption: Other
:hidden:

glossary.md
changelog.md
estimator_overview
related_software
```

==> aeon-0.4.0.tar.gz: aeon-0.4.0/docs/index.md <==
---
hide-toc: true
---

```{image} images/logo/aeon-logo-blue-compact.png
:align: center
:alt: aeon logo
:width: 80%
```
# Welcome to the documentation for **aeon**

<br>

- scikit learn compatible Framework for time series tasks such as forecasting and
classification.
- Provides a broad library of time series algorithms, including the latest advances.
- Efficient implementation of time series algorithms using numba.
- Interfaces with other time series packages to provide a single framework for algorithm
comparison.

<br>

::::{grid} 1 2 2 2
:gutter: 3

:::{grid-item-card}
:img-top: examples/forecasting/img/forecasting.png
:text-align: center


Get started with time series forecasting.

+++

```{button-ref} /examples/forecasting/forecasting.ipynb
:color: primary
:click-parent:
:expand:

Forecasting
```

:::

:::{grid-item-card}
:img-top: examples/img/tsc.png
:text-align: center




Get started with time series classification.

+++

```{button-ref} /examples/classification/classification.ipynb
:color: primary
:click-parent:
:expand:

Classification
```

:::

:::{grid-item-card}
:img-top: examples/img/tser.png
:text-align: center


Get started with time series extrinsic regression.

+++

```{button-ref} /examples/regression/regression.ipynb
:color: primary
:click-parent:
:expand:

Regression
```

:::

:::{grid-item-card}
:img-top: examples/img/tscl.png
:text-align: center


Get started with time series clustering.

+++

```{button-ref} /examples/clustering/partitional_clustering.ipynb
:color: primary
:click-parent:
:expand:

Clustering
```

:::

:::{grid-item-card}
:img-top: examples/transformations/img/transformation.png
:text-align: center


Get started with time series transformations.

+++

```{button-ref} /examples/transformations/transformations.ipynb
:color: primary
:click-parent:
:expand:

Transformations
```

:::

:::{grid-item-card}
:img-top: examples/distances/img/dtw_vis.png
:text-align: center


Get started with time series distances.

+++

```{button-ref} /examples/distances/distances.ipynb
:color: primary
:click-parent:
:expand:

Distances
```

:::

:::{grid-item-card}
:img-top: examples/annotation/img/clasp.png
:text-align: center


Annotation

+++

```{button-ref} /examples/annotation/annotation.ipynb
:color: primary
:click-parent:
:expand:

Annotation
```

:::

:::{grid-item-card}
:text-align: center


Data structures and containers used in aeon

+++

```{button-ref} /examples/datasets/datasets.ipynb
:color: primary
:click-parent:
:expand:

Data
```

:::

:::{grid-item-card}
:img-top: /examples/benchmarking/img/benchmarking.png
:text-align: center

How to benchmark algorithms.

+++

```{button-ref} /examples/benchmarking/benchmarking.ipynb
:color: primary
:click-parent:
:expand:

Benchmarking
```
:::

:::{grid-item-card}
:img-top: /examples/networks/img/Inception.png
:text-align: center

Deep learning networks.

+++

```{button-ref} /examples/networks/deep_learning.ipynb
:color: primary
:click-parent:
:expand:

Networks
```

:::

::::

## Community Channels

**GitHub**: [github.com/aeon-toolkit/aeon](https://github.com/aeon-toolkit/aeon)

**Slack**: [aeon slack](https://join.slack.com/t/aeon-toolkit/shared_invite/zt-1plkevy4x-vAg1dAUXcuoR38FjY9nxzg)

**Twitter**: [twitter/aeon-toolkit](https://twitter.com/aeon_toolkit)

**LinkedIn**: [linkedin/aeon-toolkit](https://www.linkedin.com/company/aeon-toolkit)

```{toctree}
:caption: Using aeon
:hidden:

installation.md
getting_started.md
user_guide
api_reference
examples.md
```

```{toctree}
:caption: Developing aeon
:hidden:

get_involved
developers
```

```{toctree}
:caption: The aeon team
:hidden:

contributors.md
about.md
```

```{toctree}
:caption: Other
:hidden:

glossary.md
changelog.md
related_software
```
